==> emmaramirez.me-0.11.2.tgz: package/CHANGELOG.md <==
<a name="0.11.2"></a>
## [0.11.2](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.11.1...0.11.2) (2018-06-18)


### Bug Fixes

* change h1 => h2, add notes on --yes flag ([0a4a793](https://github.com/EmmaRamirez/emmaramirez.me/commit/0a4a793))



<a name="0.11.1"></a>
## [0.11.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.11.0...0.11.1) (2018-06-18)


### Bug Fixes

* save writing ([5a74acb](https://github.com/EmmaRamirez/emmaramirez.me/commit/5a74acb))



<a name="0.11.0"></a>
# [0.11.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.8...0.11.0) (2018-06-18)


### Bug Fixes

* gramamr ([b8dfe9c](https://github.com/EmmaRamirez/emmaramirez.me/commit/b8dfe9c))
* grammar error, nice => niche ([a74202f](https://github.com/EmmaRamirez/emmaramirez.me/commit/a74202f))



<a name="0.10.8"></a>
## [0.10.8](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.7...0.10.8) (2018-06-14)


### Bug Fixes

* proper emoji for new article ([9ba0d8c](https://github.com/EmmaRamirez/emmaramirez.me/commit/9ba0d8c))



<a name="0.10.7"></a>
## [0.10.7](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.6...0.10.7) (2018-06-13)


### Bug Fixes

* strip doublequotes in description ([c950d2c](https://github.com/EmmaRamirez/emmaramirez.me/commit/c950d2c))



<a name="0.10.6"></a>
## [0.10.6](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.5...0.10.6) (2018-05-06)


### Bug Fixes

* correct first post ([32892d4](https://github.com/EmmaRamirez/emmaramirez.me/commit/32892d4))



<a name="0.10.5"></a>
## [0.10.5](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.4...0.10.5) (2018-01-15)



<a name="0.10.4"></a>
## [0.10.4](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.2...0.10.4) (2018-01-15)


### Bug Fixes

* **styles:** add margin 0 auto to ([fdf094c](https://github.com/EmmaRamirez/emmaramirez.me/commit/fdf094c))
* **Tags:** fix error where Tags broke ([e6905ad](https://github.com/EmmaRamirez/emmaramirez.me/commit/e6905ad))
* add keyword + description meta tags to posts ([1079cbc](https://github.com/EmmaRamirez/emmaramirez.me/commit/1079cbc))
* add publish command ([5936c89](https://github.com/EmmaRamirez/emmaramirez.me/commit/5936c89))
* spruce up projects section ([8365a7d](https://github.com/EmmaRamirez/emmaramirez.me/commit/8365a7d))



<a name="0.10.2"></a>
## [0.10.2](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.1...0.10.2) (2018-01-14)


### Bug Fixes

* fix test errors related to Component ([5caf26a](https://github.com/EmmaRamirez/emmaramirez.me/commit/5caf26a))



<a name="0.10.1"></a>
## [0.10.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.0...0.10.1) (2018-01-14)



<a name="0.10.0"></a>
# [0.10.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.9.0...0.10.0) (2018-01-14)


### Features

* **drafts:** enable drafting a post ([823a001](https://github.com/EmmaRamirez/emmaramirez.me/commit/823a001))



<a name="0.9.0"></a>
# [0.9.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.8.0...0.9.0) (2018-01-14)


### Bug Fixes

* add sort to Tags component ([8cde27c](https://github.com/EmmaRamirez/emmaramirez.me/commit/8cde27c))
* add sort to Tags component ([262d8a2](https://github.com/EmmaRamirez/emmaramirez.me/commit/262d8a2))
* **style:** add padding to blog-post ([b2471aa](https://github.com/EmmaRamirez/emmaramirez.me/commit/b2471aa))
* ensure not passing in 'tags' breaks command ([98740bf](https://github.com/EmmaRamirez/emmaramirez.me/commit/98740bf))


### Features

* add Tags component ([a58a053](https://github.com/EmmaRamirez/emmaramirez.me/commit/a58a053))
* add tags to npm run create ([7a95b7c](https://github.com/EmmaRamirez/emmaramirez.me/commit/7a95b7c))



<a name="0.8.0"></a>
# [0.8.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.7.1...0.8.0) (2018-01-09)


### Features

* add ads to build ([b94cc32](https://github.com/EmmaRamirez/emmaramirez.me/commit/b94cc32))
* add adwords ([0a27426](https://github.com/EmmaRamirez/emmaramirez.me/commit/0a27426))



<a name="0.7.1"></a>
## [0.7.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.7.0...0.7.1) (2018-01-06)


### Bug Fixes

* **styles:** add 100% more emoji ([f26954f](https://github.com/EmmaRamirez/emmaramirez.me/commit/f26954f))
* **styles:** improve selection styles ([1ecd7d8](https://github.com/EmmaRamirez/emmaramirez.me/commit/1ecd7d8))
* **styles:** improve selection styles ([5939666](https://github.com/EmmaRamirez/emmaramirez.me/commit/5939666))
* add emoji field to npm run create ([9048fdd](https://github.com/EmmaRamirez/emmaramirez.me/commit/9048fdd))
* remove broken style switcher ([8faeedb](https://github.com/EmmaRamirez/emmaramirez.me/commit/8faeedb))
* **styles:** make item-description color darker ([73ef854](https://github.com/EmmaRamirez/emmaramirez.me/commit/73ef854))


### Features

* enable comments via Disqus ([06b4cc0](https://github.com/EmmaRamirez/emmaramirez.me/commit/06b4cc0))



<a name="0.7.0"></a>
# [0.7.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.6.6...0.7.0) (2018-01-06)


### Bug Fixes

* **styles:** fix ul styles, code styles ([6d913a7](https://github.com/EmmaRamirez/emmaramirez.me/commit/6d913a7))
* **writing:** fix broken links in post ([05c00a6](https://github.com/EmmaRamirez/emmaramirez.me/commit/05c00a6))


### Features

* finish up create new post ([6011c10](https://github.com/EmmaRamirez/emmaramirez.me/commit/6011c10))
* new post creator init ([a75f1d9](https://github.com/EmmaRamirez/emmaramirez.me/commit/a75f1d9))



<a name="0.6.6"></a>
## [0.6.6](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.6.5...0.6.6) (2018-01-02)


### Bug Fixes

* add google analytics ([db8cd00](https://github.com/EmmaRamirez/emmaramirez.me/commit/db8cd00))
* **styles:** fix styling to be more responsive + viewport tag ([10f3d20](https://github.com/EmmaRamirez/emmaramirez.me/commit/10f3d20))



<a name="0.6.5"></a>
## [0.6.5](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.6.4...0.6.5) (2018-01-02)


### Bug Fixes

* **styles:** blogpost width to 55rem ([00ece37](https://github.com/EmmaRamirez/emmaramirez.me/commit/00ece37))


### Features

* add dates to items ([59fba6d](https://github.com/EmmaRamirez/emmaramirez.me/commit/59fba6d))



<a name="0.6.4"></a>
## [0.6.4](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.6.3...0.6.4) (2017-12-30)


### Bug Fixes

* fix 'possibly undefined' err in test ([e713eb8](https://github.com/EmmaRamirez/emmaramirez.me/commit/e713eb8))



<a name="0.6.3"></a>
## [0.6.3](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.6.2...v0.6.3) (2017-12-30)


### Bug Fixes

* **styles:** fixes improper link color on frontpage ([9c297fd](https://github.com/EmmaRamirez/emmaramirez.me/commit/9c297fd)), closes [#13](https://github.com/EmmaRamirez/emmaramirez.me/issues/13)



<a name="0.6.2"></a>
## [0.6.2](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.6.1...v0.6.2) (2017-12-30)


### Bug Fixes

* add proper link color ([5c67f59](https://github.com/EmmaRamirez/emmaramirez.me/commit/5c67f59))
* style tweaks to stats in dark mode ([e5f6782](https://github.com/EmmaRamirez/emmaramirez.me/commit/e5f6782))



<a name="0.6.1"></a>
## [0.6.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.6.0...v0.6.1) (2017-12-29)


### Bug Fixes

* enable syntax highlighting ([cb9e592](https://github.com/EmmaRamirez/emmaramirez.me/commit/cb9e592))



<a name="0.6.0"></a>
# [0.6.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.5.0...v0.6.0) (2017-12-29)


### Bug Fixes

* attempt fix for gh-pages ([4fd0664](https://github.com/EmmaRamirez/emmaramirez.me/commit/4fd0664))
* move src/posts => posts ([4836470](https://github.com/EmmaRamirez/emmaramirez.me/commit/4836470))
* remove oyster script ([2b2c6ba](https://github.com/EmmaRamirez/emmaramirez.me/commit/2b2c6ba))
* resolve test broken due to localStorage() ([2e5e905](https://github.com/EmmaRamirez/emmaramirez.me/commit/2e5e905))
* updates to tests ([970d4f5](https://github.com/EmmaRamirez/emmaramirez.me/commit/970d4f5))


### Features

* **blog:** add first post ([a62c09e](https://github.com/EmmaRamirez/emmaramirez.me/commit/a62c09e))
* add status badges to site ([a664df2](https://github.com/EmmaRamirez/emmaramirez.me/commit/a664df2))



<a name="0.5.0"></a>
# [0.5.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.4.0...v0.5.0) (2017-12-27)



<a name="0.4.0"></a>
# [0.4.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.3.0...v0.4.0) (2017-12-27)



<a name="0.3.0"></a>
# [0.3.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.2.0...v0.3.0) (2017-12-27)



<a name="0.2.0"></a>
# [0.2.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.0.0...v0.2.0) (2017-12-27)



<a name="0.0.0"></a>
# [0.0.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/ae07008...v0.0.0) (2017-12-27)


### Bug Fixes

* add some media queries ([b08938c](https://github.com/EmmaRamirez/emmaramirez.me/commit/b08938c))
* links work in night mode ([94e137c](https://github.com/EmmaRamirez/emmaramirez.me/commit/94e137c))
* make webpack actually work ([b33c924](https://github.com/EmmaRamirez/emmaramirez.me/commit/b33c924))
* public => docs ([eed4484](https://github.com/EmmaRamirez/emmaramirez.me/commit/eed4484))


### Features

* add bitcoin/eth addresses ([02dc8e5](https://github.com/EmmaRamirez/emmaramirez.me/commit/02dc8e5))
* add ElsewhereLinks component ([af4c7aa](https://github.com/EmmaRamirez/emmaramirez.me/commit/af4c7aa))
* add personal icons ([7a338bb](https://github.com/EmmaRamirez/emmaramirez.me/commit/7a338bb))
* add style switcher ([5752918](https://github.com/EmmaRamirez/emmaramirez.me/commit/5752918))
* App component ([f06b8d4](https://github.com/EmmaRamirez/emmaramirez.me/commit/f06b8d4))
* better render() util, App ([c334c93](https://github.com/EmmaRamirez/emmaramirez.me/commit/c334c93))
* **projects:** add fakemon idea generator, nuzlocke template generator, palm trees as webp ([9c9aacd](https://github.com/EmmaRamirez/emmaramirez.me/commit/9c9aacd))
* Header component ([e7666b3](https://github.com/EmmaRamirez/emmaramirez.me/commit/e7666b3))
* include scripts in webpack ([3d17b59](https://github.com/EmmaRamirez/emmaramirez.me/commit/3d17b59))
* List component ([a252636](https://github.com/EmmaRamirez/emmaramirez.me/commit/a252636))
* update config, build step ([ae07008](https://github.com/EmmaRamirez/emmaramirez.me/commit/ae07008))

==> emmaramirez.me-0.13.2.tgz: package/CHANGELOG.md <==
<a name="0.13.2"></a>
## [0.13.2](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.13.1...0.13.2) (2018-07-01)


### Bug Fixes

* improve rendering times + methods ([4ce3038](https://github.com/EmmaRamirez/emmaramirez.me/commit/4ce3038))



<a name="0.13.1"></a>
## [0.13.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.13.0...0.13.1) (2018-07-01)



<a name="0.13.0"></a>
# [0.13.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.12.0...0.13.0) (2018-07-01)


### Bug Fixes

* increase padding for projects ([fa558a9](https://github.com/EmmaRamirez/emmaramirez.me/commit/fa558a9))


### Features

* **tags:** add build-tags script ([57de79d](https://github.com/EmmaRamirez/emmaramirez.me/commit/57de79d))
* **tags:** modify data format to support tags ([67d5a53](https://github.com/EmmaRamirez/emmaramirez.me/commit/67d5a53))
* **tags:** modify scripts to work with tags build ([7b34e64](https://github.com/EmmaRamirez/emmaramirez.me/commit/7b34e64))



<a name="0.12.0"></a>
# [0.12.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.11.3...0.12.0) (2018-06-30)


### Features

* add new fields for projects, upgrade webpack ([6f0dc1e](https://github.com/EmmaRamirez/emmaramirez.me/commit/6f0dc1e))
* redesign of projects list ([5584c9b](https://github.com/EmmaRamirez/emmaramirez.me/commit/5584c9b))



<a name="0.11.3"></a>
## [0.11.3](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.11.2...0.11.3) (2018-06-24)



<a name="0.11.2"></a>
## [0.11.2](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.11.1...0.11.2) (2018-06-18)


### Bug Fixes

* change h1 => h2, add notes on --yes flag ([0a4a793](https://github.com/EmmaRamirez/emmaramirez.me/commit/0a4a793))



<a name="0.11.1"></a>
## [0.11.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.11.0...0.11.1) (2018-06-18)


### Bug Fixes

* save writing ([5a74acb](https://github.com/EmmaRamirez/emmaramirez.me/commit/5a74acb))



<a name="0.11.0"></a>
# [0.11.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.8...0.11.0) (2018-06-18)


### Bug Fixes

* gramamr ([b8dfe9c](https://github.com/EmmaRamirez/emmaramirez.me/commit/b8dfe9c))
* grammar error, nice => niche ([a74202f](https://github.com/EmmaRamirez/emmaramirez.me/commit/a74202f))



<a name="0.10.8"></a>
## [0.10.8](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.7...0.10.8) (2018-06-14)


### Bug Fixes

* proper emoji for new article ([9ba0d8c](https://github.com/EmmaRamirez/emmaramirez.me/commit/9ba0d8c))



<a name="0.10.7"></a>
## [0.10.7](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.6...0.10.7) (2018-06-13)


### Bug Fixes

* strip doublequotes in description ([c950d2c](https://github.com/EmmaRamirez/emmaramirez.me/commit/c950d2c))



<a name="0.10.6"></a>
## [0.10.6](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.5...0.10.6) (2018-05-06)


### Bug Fixes

* correct first post ([32892d4](https://github.com/EmmaRamirez/emmaramirez.me/commit/32892d4))



<a name="0.10.5"></a>
## [0.10.5](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.4...0.10.5) (2018-01-15)



<a name="0.10.4"></a>
## [0.10.4](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.10.3...0.10.4) (2018-01-15)


### Bug Fixes

* add publish command ([5936c89](https://github.com/EmmaRamirez/emmaramirez.me/commit/5936c89))



<a name="0.10.3"></a>
## [0.10.3](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.10.2...v0.10.3) (2018-01-15)


### Bug Fixes

* **styles:** add margin 0 auto to ([fdf094c](https://github.com/EmmaRamirez/emmaramirez.me/commit/fdf094c))
* **Tags:** fix error where Tags broke ([e6905ad](https://github.com/EmmaRamirez/emmaramirez.me/commit/e6905ad))
* add keyword + description meta tags to posts ([1079cbc](https://github.com/EmmaRamirez/emmaramirez.me/commit/1079cbc))
* spruce up projects section ([8365a7d](https://github.com/EmmaRamirez/emmaramirez.me/commit/8365a7d))



<a name="0.10.2"></a>
## [0.10.2](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.2...v0.10.2) (2018-01-14)


### Bug Fixes

* fix test errors related to Component ([5caf26a](https://github.com/EmmaRamirez/emmaramirez.me/commit/5caf26a))



<a name="0.10.1"></a>
## [0.10.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.1...v0.10.1) (2018-01-14)



<a name="0.10.0"></a>
# [0.10.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.10.0...v0.10.0) (2018-01-14)


### Features

* **drafts:** enable drafting a post ([823a001](https://github.com/EmmaRamirez/emmaramirez.me/commit/823a001))



<a name="0.9.0"></a>
# [0.9.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.9.0...v0.9.0) (2018-01-14)


### Bug Fixes

* add sort to Tags component ([8cde27c](https://github.com/EmmaRamirez/emmaramirez.me/commit/8cde27c))
* add sort to Tags component ([262d8a2](https://github.com/EmmaRamirez/emmaramirez.me/commit/262d8a2))
* **style:** add padding to blog-post ([b2471aa](https://github.com/EmmaRamirez/emmaramirez.me/commit/b2471aa))
* ensure not passing in 'tags' breaks command ([98740bf](https://github.com/EmmaRamirez/emmaramirez.me/commit/98740bf))


### Features

* add Tags component ([a58a053](https://github.com/EmmaRamirez/emmaramirez.me/commit/a58a053))
* add tags to npm run create ([7a95b7c](https://github.com/EmmaRamirez/emmaramirez.me/commit/7a95b7c))



<a name="0.8.0"></a>
# [0.8.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.8.0...v0.8.0) (2018-01-11)



<a name="0.8.0"></a>
# [0.8.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.7.1...0.8.0) (2018-01-09)


### Features

* add ads to build ([b94cc32](https://github.com/EmmaRamirez/emmaramirez.me/commit/b94cc32))
* add adwords ([0a27426](https://github.com/EmmaRamirez/emmaramirez.me/commit/0a27426))



<a name="0.7.1"></a>
## [0.7.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.7.1...v0.7.1) (2018-01-06)


### Bug Fixes

* **styles:** add 100% more emoji ([f26954f](https://github.com/EmmaRamirez/emmaramirez.me/commit/f26954f))
* **styles:** improve selection styles ([1ecd7d8](https://github.com/EmmaRamirez/emmaramirez.me/commit/1ecd7d8))
* **styles:** improve selection styles ([5939666](https://github.com/EmmaRamirez/emmaramirez.me/commit/5939666))
* add emoji field to npm run create ([9048fdd](https://github.com/EmmaRamirez/emmaramirez.me/commit/9048fdd))
* remove broken style switcher ([8faeedb](https://github.com/EmmaRamirez/emmaramirez.me/commit/8faeedb))
* **styles:** make item-description color darker ([73ef854](https://github.com/EmmaRamirez/emmaramirez.me/commit/73ef854))


### Features

* enable comments via Disqus ([06b4cc0](https://github.com/EmmaRamirez/emmaramirez.me/commit/06b4cc0))



<a name="0.7.0"></a>
# [0.7.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.7.0...v0.7.0) (2018-01-06)


### Bug Fixes

* **styles:** fix ul styles, code styles ([6d913a7](https://github.com/EmmaRamirez/emmaramirez.me/commit/6d913a7))
* **writing:** fix broken links in post ([05c00a6](https://github.com/EmmaRamirez/emmaramirez.me/commit/05c00a6))


### Features

* finish up create new post ([6011c10](https://github.com/EmmaRamirez/emmaramirez.me/commit/6011c10))
* new post creator init ([a75f1d9](https://github.com/EmmaRamirez/emmaramirez.me/commit/a75f1d9))



<a name="0.6.6"></a>
## [0.6.6](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.6.6...v0.6.6) (2018-01-02)


### Bug Fixes

* add google analytics ([db8cd00](https://github.com/EmmaRamirez/emmaramirez.me/commit/db8cd00))
* **styles:** fix styling to be more responsive + viewport tag ([10f3d20](https://github.com/EmmaRamirez/emmaramirez.me/commit/10f3d20))



<a name="0.6.5"></a>
## [0.6.5](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.6.5...v0.6.5) (2018-01-02)


### Bug Fixes

* **styles:** blogpost width to 55rem ([00ece37](https://github.com/EmmaRamirez/emmaramirez.me/commit/00ece37))


### Features

* add dates to items ([59fba6d](https://github.com/EmmaRamirez/emmaramirez.me/commit/59fba6d))



<a name="0.6.4"></a>
## [0.6.4](https://github.com/EmmaRamirez/emmaramirez.me/compare/0.6.4...v0.6.4) (2017-12-30)


### Bug Fixes

* fix 'possibly undefined' err in test ([e713eb8](https://github.com/EmmaRamirez/emmaramirez.me/commit/e713eb8))



<a name="0.6.3"></a>
## [0.6.3](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.6.2...v0.6.3) (2017-12-30)


### Bug Fixes

* **styles:** fixes improper link color on frontpage ([9c297fd](https://github.com/EmmaRamirez/emmaramirez.me/commit/9c297fd)), closes [#13](https://github.com/EmmaRamirez/emmaramirez.me/issues/13)



<a name="0.6.2"></a>
## [0.6.2](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.6.1...v0.6.2) (2017-12-30)


### Bug Fixes

* add proper link color ([5c67f59](https://github.com/EmmaRamirez/emmaramirez.me/commit/5c67f59))
* style tweaks to stats in dark mode ([e5f6782](https://github.com/EmmaRamirez/emmaramirez.me/commit/e5f6782))



<a name="0.6.1"></a>
## [0.6.1](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.6.0...v0.6.1) (2017-12-29)


### Bug Fixes

* enable syntax highlighting ([cb9e592](https://github.com/EmmaRamirez/emmaramirez.me/commit/cb9e592))



<a name="0.6.0"></a>
# [0.6.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.0.0...v0.6.0) (2017-12-29)


### Bug Fixes

* attempt fix for gh-pages ([4fd0664](https://github.com/EmmaRamirez/emmaramirez.me/commit/4fd0664))
* move src/posts => posts ([4836470](https://github.com/EmmaRamirez/emmaramirez.me/commit/4836470))
* remove oyster script ([2b2c6ba](https://github.com/EmmaRamirez/emmaramirez.me/commit/2b2c6ba))
* resolve test broken due to localStorage() ([2e5e905](https://github.com/EmmaRamirez/emmaramirez.me/commit/2e5e905))
* updates to tests ([970d4f5](https://github.com/EmmaRamirez/emmaramirez.me/commit/970d4f5))


### Features

* **blog:** add first post ([a62c09e](https://github.com/EmmaRamirez/emmaramirez.me/commit/a62c09e))
* add status badges to site ([a664df2](https://github.com/EmmaRamirez/emmaramirez.me/commit/a664df2))



<a name="0.0.0"></a>
# [0.0.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.5.0...v0.0.0) (2017-12-27)



<a name="0.5.0"></a>
# [0.5.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.4.0...v0.5.0) (2017-12-27)


### Bug Fixes

* add some media queries ([b08938c](https://github.com/EmmaRamirez/emmaramirez.me/commit/b08938c))
* links work in night mode ([94e137c](https://github.com/EmmaRamirez/emmaramirez.me/commit/94e137c))


### Features

* **projects:** add fakemon idea generator, nuzlocke template generator, palm trees as webp ([9c9aacd](https://github.com/EmmaRamirez/emmaramirez.me/commit/9c9aacd))
* add bitcoin/eth addresses ([02dc8e5](https://github.com/EmmaRamirez/emmaramirez.me/commit/02dc8e5))
* add ElsewhereLinks component ([af4c7aa](https://github.com/EmmaRamirez/emmaramirez.me/commit/af4c7aa))
* add personal icons ([7a338bb](https://github.com/EmmaRamirez/emmaramirez.me/commit/7a338bb))



<a name="0.4.0"></a>
# [0.4.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.3.0...v0.4.0) (2017-12-27)


### Bug Fixes

* public => docs ([eed4484](https://github.com/EmmaRamirez/emmaramirez.me/commit/eed4484))


### Features

* add style switcher ([5752918](https://github.com/EmmaRamirez/emmaramirez.me/commit/5752918))



<a name="0.3.0"></a>
# [0.3.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/v0.2.0...v0.3.0) (2017-12-26)


### Features

* App component ([f06b8d4](https://github.com/EmmaRamirez/emmaramirez.me/commit/f06b8d4))
* better render() util, App ([c334c93](https://github.com/EmmaRamirez/emmaramirez.me/commit/c334c93))
* Header component ([e7666b3](https://github.com/EmmaRamirez/emmaramirez.me/commit/e7666b3))
* List component ([a252636](https://github.com/EmmaRamirez/emmaramirez.me/commit/a252636))



<a name="0.2.0"></a>
# [0.2.0](https://github.com/EmmaRamirez/emmaramirez.me/compare/ae07008...v0.2.0) (2017-12-25)


### Bug Fixes

* make webpack actually work ([b33c924](https://github.com/EmmaRamirez/emmaramirez.me/commit/b33c924))


### Features

* include scripts in webpack ([3d17b59](https://github.com/EmmaRamirez/emmaramirez.me/commit/3d17b59))
* update config, build step ([ae07008](https://github.com/EmmaRamirez/emmaramirez.me/commit/ae07008))
